require 'uu/os/rest/dto'
require 'uu/os/uesuri'



module UU
  module ADK
    module App
      # App Set Attributes DTO.
      # @deprecated Use {UU::OS::AppMetaModel::AppMetaModelSetAttributes} instead.
      class AppSetAttributes < UU::OS::REST::DTO

        # The new name of the app. When nil is set, the name is not modified.
        attr_accessor :name

        # The new code of the app. When nil is set, the code is not modified.
        # The code must be unique in a given territory, otherwise thesetAttributes command
        # fails.
        attr_accessor :code

        # The new description of the app. When nil is set, the description
        # is not modified.
        attr_accessor :description

        # The new security level of the app. When nil is set, the security
        # level is not modified. If the meta artifact tSecurityLevel is higher than the user's
        # security clearance, the setAttributes command fails.
        attr_accessor :security_level

        # URI of the app's icon. When nil is set, the icon is not modified.
        # When nil URI ("ues:{[-1]}:{[-1]}:") value is set, the app icon is removed
        # and the app uses icon from meta artifact.
        #
        # @example Allowed format of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{CODE_OF_ICON}
        #
        # @example An example of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{ART_077}
        attr_accessor :icon_uri

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

      end
    end

  end
end
